CpuSnapshot class

Represents a single CPU snapshot

Constructors

CpuSnapshot({required DateTime timestamp, required double cpuUsage, required int userTime, required int systemTime, required int idleTime})
const
CpuSnapshot.fromJson(Map<String, dynamic> json)
Creates snapshot from JSON data
factory

Properties

cpuUsage double
final
hashCode int
The hash code for this object.
no setterinherited
idleTime int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemTime int
final
timestamp DateTime
final
totalTime int
Total CPU time (user + system + idle)
no setter
userTime int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts snapshot to JSON format
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited