WidgetPerformanceSummary class
Widget performance summary
Constructors
- WidgetPerformanceSummary({required int totalTests, required double averageBuildTime, required String fastestTest, required String slowestTest})
-
const
Properties
- averageBuildTime → double
-
final
- fastestTest → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slowestTest → String
-
final
- totalTests → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts summary to JSON format
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited