BenchmarkTest class
Represents a single benchmark test
Constructors
-
BenchmarkTest({required String name, required Future<
void> testFunction(), required int iterations, String description = ''}) -
const
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations → int
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
testFunction
→ Future<
void> Function() -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited