StartupReport class
Startup performance report
Constructors
-
StartupReport({DateTime? startTime, DateTime? endTime, int? startupTime, int? startupTimeMicroseconds, required List<
StartupEvent> events}) -
const
Properties
- endTime → DateTime?
-
final
-
events
→ List<
StartupEvent> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
Whether startup timing is complete
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime?
-
final
- startupTime → int?
-
final
- startupTimeMicroseconds → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts report to JSON format
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited