WidgetPerformanceTester class
Widget performance tester for measuring widget rendering performance
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ Map<
String, WidgetTestResult> -
Gets all test results
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearResults(
) → void - Clears all test results
-
exportData(
) → Map< String, dynamic> - Exports all test data to JSON format
-
generateReport(
) → WidgetPerformanceReport - Generates a comprehensive performance report
-
getResult(
String testName) → WidgetTestResult? - Gets a specific test result
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
testWidgetBuild(
String testName, Future< void> buildFunction(), {int iterations = 100, String description = ''}) → Future<WidgetTestResult> - Tests widget build performance
-
testWidgetLayout(
String testName, Future< void> layoutFunction(), {int iterations = 100, String description = ''}) → Future<WidgetTestResult> - Tests widget layout performance
-
testWidgetRebuild(
String testName, Future< void> rebuildFunction(), {int iterations = 100, String description = ''}) → Future<WidgetTestResult> - Tests widget rebuild performance
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited